# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryOrganizationsExpanded(BaseModel):
    organizations: Optional["QueryOrganizationsExpandedOrganizations"]


class QueryOrganizationsExpandedOrganizations(BaseModel):
    results: Optional[List[Optional["QueryOrganizationsExpandedOrganizationsResults"]]]


class QueryOrganizationsExpandedOrganizationsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryOrganizationsExpandedOrganizationsResultsOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsFeeds"]]
    ]
    links: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsLinks"]]
    ]
    workflow: Optional["QueryOrganizationsExpandedOrganizationsResultsWorkflow"]
    location: Optional["QueryOrganizationsExpandedOrganizationsResultsLocation"]
    h_3: Optional["QueryOrganizationsExpandedOrganizationsResultsH3"] = Field(
        alias="h3"
    )
    address: Optional["QueryOrganizationsExpandedOrganizationsResultsAddress"]
    founding_date: Optional[Any] = Field(alias="foundingDate")
    email: Optional[str]
    telephone: Optional[str]
    legal_name: Optional[str] = Field(alias="legalName")
    industries: Optional[List[Optional[str]]]
    revenue: Optional[Any]
    revenue_currency: Optional[str] = Field(alias="revenueCurrency")
    investment: Optional[Any]
    investment_currency: Optional[str] = Field(alias="investmentCurrency")
    founders: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsFounders"]]
    ]
    employees: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsEmployees"]]
    ]
    members: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsMembers"]]
    ]
    parent_organization: Optional[
        "QueryOrganizationsExpandedOrganizationsResultsParentOrganization"
    ] = Field(alias="parentOrganization")
    member_of: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsMemberOf"]]
    ] = Field(alias="memberOf")
    sub_organizations: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsSubOrganizations"]]
    ] = Field(alias="subOrganizations")
    locations: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsLocations"]]
    ]
    investments_received: Optional[
        List[
            Optional[
                "QueryOrganizationsExpandedOrganizationsResultsInvestmentsReceived"
            ]
        ]
    ] = Field(alias="investmentsReceived")
    investor_funds: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsInvestorFunds"]]
    ] = Field(alias="investorFunds")


class QueryOrganizationsExpandedOrganizationsResultsOwner(BaseModel):
    id: str


class QueryOrganizationsExpandedOrganizationsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryOrganizationsExpandedOrganizationsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryOrganizationsExpandedOrganizationsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryOrganizationsExpandedOrganizationsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryOrganizationsExpandedOrganizationsResultsFounders(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsEmployees(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsMembers(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsParentOrganization(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsMemberOf(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsSubOrganizations(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsLocations(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsInvestmentsReceived(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsInvestorFunds(BaseModel):
    id: str
    name: str


QueryOrganizationsExpanded.model_rebuild()
QueryOrganizationsExpandedOrganizations.model_rebuild()
QueryOrganizationsExpandedOrganizationsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ObservableTypes


class MatchEntity(BaseModel):
    match_entity: Optional["MatchEntityMatchEntity"] = Field(alias="matchEntity")


class MatchEntityMatchEntity(BaseModel):
    reference: Optional["MatchEntityMatchEntityReference"]
    relevance: Optional[float]
    reasoning: Optional[str]


class MatchEntityMatchEntityReference(BaseModel):
    type: ObservableTypes
    observable: "MatchEntityMatchEntityReferenceObservable"


class MatchEntityMatchEntityReferenceObservable(BaseModel):
    id: str
    name: Optional[str]


MatchEntity.model_rebuild()
MatchEntityMatchEntity.model_rebuild()
MatchEntityMatchEntityReference.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCategory(BaseModel):
    category: Optional["GetCategoryCategory"]


class GetCategoryCategory(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    feeds: Optional[List[Optional["GetCategoryCategoryFeeds"]]]


class GetCategoryCategoryFeeds(BaseModel):
    id: str
    name: str


GetCategory.model_rebuild()
GetCategoryCategory.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    CalendarAttendeeResponseStatus,
    CalendarEventStatus,
    CalendarEventVisibility,
    CalendarRecurrencePattern,
    CalendarReminderMethod,
    ContentTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    MailImportance,
    MailPriority,
    MailSensitivity,
    ObservableTypes,
    OccurrenceTypes,
    OrientationTypes,
    TextRoles,
)


class QueryContentsObservations(BaseModel):
    contents: Optional["QueryContentsObservationsContents"]


class QueryContentsObservationsContents(BaseModel):
    results: Optional[List[Optional["QueryContentsObservationsContentsResults"]]]


class QueryContentsObservationsContentsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryContentsObservationsContentsResultsOwner"
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    finished_date: Optional[Any] = Field(alias="finishedDate")
    workflow_duration: Optional[Any] = Field(alias="workflowDuration")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    address: Optional["QueryContentsObservationsContentsResultsAddress"]
    location: Optional["QueryContentsObservationsContentsResultsLocation"]
    features: Optional[str]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    relative_folder_path: Optional[str] = Field(alias="relativeFolderPath")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    snapshots_uri: Optional[Any] = Field(alias="snapshotsUri")
    snapshot_count: Optional[int] = Field(alias="snapshotCount")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    quotes: Optional[List[str]]
    video: Optional["QueryContentsObservationsContentsResultsVideo"]
    audio: Optional["QueryContentsObservationsContentsResultsAudio"]
    image: Optional["QueryContentsObservationsContentsResultsImage"]
    document: Optional["QueryContentsObservationsContentsResultsDocument"]
    email: Optional["QueryContentsObservationsContentsResultsEmail"]
    event: Optional["QueryContentsObservationsContentsResultsEvent"]
    issue: Optional["QueryContentsObservationsContentsResultsIssue"]
    commit: Optional["QueryContentsObservationsContentsResultsCommit"]
    pull_request: Optional["QueryContentsObservationsContentsResultsPullRequest"] = (
        Field(alias="pullRequest")
    )
    message: Optional["QueryContentsObservationsContentsResultsMessage"]
    post: Optional["QueryContentsObservationsContentsResultsPost"]
    package: Optional["QueryContentsObservationsContentsResultsPackage"]
    language: Optional["QueryContentsObservationsContentsResultsLanguage"]
    feed: Optional["QueryContentsObservationsContentsResultsFeed"]
    workflow: Optional["QueryContentsObservationsContentsResultsWorkflow"]
    pages: Optional[List["QueryContentsObservationsContentsResultsPages"]]
    segments: Optional[List["QueryContentsObservationsContentsResultsSegments"]]
    frames: Optional[List["QueryContentsObservationsContentsResultsFrames"]]
    error: Optional[str]
    markdown: Optional[str]
    observations: Optional[
        List[Optional["QueryContentsObservationsContentsResultsObservations"]]
    ]


class QueryContentsObservationsContentsResultsOwner(BaseModel):
    id: str


class QueryContentsObservationsContentsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryContentsObservationsContentsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryContentsObservationsContentsResultsVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class QueryContentsObservationsContentsResultsAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class QueryContentsObservationsContentsResultsImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class QueryContentsObservationsContentsResultsDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    last_modified_by: Optional[str] = Field(alias="lastModifiedBy")
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class QueryContentsObservationsContentsResultsEmail(BaseModel):
    identifier: Optional[str]
    thread_identifier: Optional[str] = Field(alias="threadIdentifier")
    subject: Optional[str]
    labels: Optional[List[Optional[str]]]
    sensitivity: Optional[MailSensitivity]
    priority: Optional[MailPriority]
    importance: Optional[MailImportance]
    unsubscribe_url: Optional[str] = Field(alias="unsubscribeUrl")
    publication_name: Optional[str] = Field(alias="publicationName")
    publication_url: Optional[str] = Field(alias="publicationUrl")
    attachment_count: Optional[int] = Field(alias="attachmentCount")
    from_: Optional[
        List[Optional["QueryContentsObservationsContentsResultsEmailFrom"]]
    ] = Field(alias="from")
    to: Optional[List[Optional["QueryContentsObservationsContentsResultsEmailTo"]]]
    cc: Optional[List[Optional["QueryContentsObservationsContentsResultsEmailCc"]]]
    bcc: Optional[List[Optional["QueryContentsObservationsContentsResultsEmailBcc"]]]


class QueryContentsObservationsContentsResultsEmailFrom(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsEmailTo(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsEmailCc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsEmailBcc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsEvent(BaseModel):
    event_identifier: Optional[str] = Field(alias="eventIdentifier")
    calendar_identifier: Optional[str] = Field(alias="calendarIdentifier")
    subject: Optional[str]
    start_date_time: Optional[Any] = Field(alias="startDateTime")
    end_date_time: Optional[Any] = Field(alias="endDateTime")
    is_all_day: Optional[bool] = Field(alias="isAllDay")
    timezone: Optional[str]
    status: Optional[CalendarEventStatus]
    visibility: Optional[CalendarEventVisibility]
    meeting_link: Optional[str] = Field(alias="meetingLink")
    organizer: Optional["QueryContentsObservationsContentsResultsEventOrganizer"]
    attendees: Optional[
        List[Optional["QueryContentsObservationsContentsResultsEventAttendees"]]
    ]
    categories: Optional[List[Optional[str]]]
    reminders: Optional[
        List[Optional["QueryContentsObservationsContentsResultsEventReminders"]]
    ]
    recurrence: Optional["QueryContentsObservationsContentsResultsEventRecurrence"]
    recurring_event_identifier: Optional[str] = Field(alias="recurringEventIdentifier")
    is_recurring: Optional[bool] = Field(alias="isRecurring")


class QueryContentsObservationsContentsResultsEventOrganizer(BaseModel):
    name: Optional[str]
    email: Optional[str]
    is_optional: Optional[bool] = Field(alias="isOptional")
    is_organizer: Optional[bool] = Field(alias="isOrganizer")
    response_status: Optional[CalendarAttendeeResponseStatus] = Field(
        alias="responseStatus"
    )


class QueryContentsObservationsContentsResultsEventAttendees(BaseModel):
    name: Optional[str]
    email: Optional[str]
    is_optional: Optional[bool] = Field(alias="isOptional")
    is_organizer: Optional[bool] = Field(alias="isOrganizer")
    response_status: Optional[CalendarAttendeeResponseStatus] = Field(
        alias="responseStatus"
    )


class QueryContentsObservationsContentsResultsEventReminders(BaseModel):
    minutes_before: Optional[int] = Field(alias="minutesBefore")
    method: Optional[CalendarReminderMethod]


class QueryContentsObservationsContentsResultsEventRecurrence(BaseModel):
    pattern: Optional[CalendarRecurrencePattern]
    interval: Optional[int]
    count: Optional[int]
    until: Optional[Any]
    days_of_week: Optional[List[Optional[str]]] = Field(alias="daysOfWeek")
    day_of_month: Optional[int] = Field(alias="dayOfMonth")
    month_of_year: Optional[int] = Field(alias="monthOfYear")


class QueryContentsObservationsContentsResultsIssue(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    project: Optional[str]
    team: Optional[str]
    status: Optional[str]
    priority: Optional[str]
    type: Optional[str]
    labels: Optional[List[Optional[str]]]


class QueryContentsObservationsContentsResultsCommit(BaseModel):
    sha: Optional[str]
    message: Optional[str]
    project: Optional[str]
    team: Optional[str]
    branch: Optional[str]
    parent_shas: Optional[List[Optional[str]]] = Field(alias="parentShas")
    files_changed: Optional[int] = Field(alias="filesChanged")
    additions: Optional[int]
    deletions: Optional[int]
    pull_request_number: Optional[str] = Field(alias="pullRequestNumber")
    author_date: Optional[Any] = Field(alias="authorDate")
    committer_date: Optional[Any] = Field(alias="committerDate")
    authors: Optional[
        List[Optional["QueryContentsObservationsContentsResultsCommitAuthors"]]
    ]
    committers: Optional[
        List[Optional["QueryContentsObservationsContentsResultsCommitCommitters"]]
    ]
    labels: Optional[List[Optional[str]]]
    links: Optional[List[Optional[Any]]]


class QueryContentsObservationsContentsResultsCommitAuthors(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsCommitCommitters(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsPullRequest(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    description: Optional[str]
    project: Optional[str]
    team: Optional[str]
    status: Optional[str]
    type: Optional[str]
    base_branch: Optional[str] = Field(alias="baseBranch")
    head_branch: Optional[str] = Field(alias="headBranch")
    is_draft: Optional[bool] = Field(alias="isDraft")
    is_mergeable: Optional[bool] = Field(alias="isMergeable")
    merge_commit_sha: Optional[str] = Field(alias="mergeCommitSha")
    merged_at: Optional[Any] = Field(alias="mergedAt")
    files_changed: Optional[int] = Field(alias="filesChanged")
    additions: Optional[int]
    deletions: Optional[int]
    authors: Optional[
        List[Optional["QueryContentsObservationsContentsResultsPullRequestAuthors"]]
    ]
    reviewers: Optional[
        List[Optional["QueryContentsObservationsContentsResultsPullRequestReviewers"]]
    ]
    labels: Optional[List[Optional[str]]]
    links: Optional[List[Optional[Any]]]


class QueryContentsObservationsContentsResultsPullRequestAuthors(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsPullRequestReviewers(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsMessage(BaseModel):
    identifier: Optional[str]
    conversation_identifier: Optional[str] = Field(alias="conversationIdentifier")
    channel_identifier: Optional[str] = Field(alias="channelIdentifier")
    channel_name: Optional[str] = Field(alias="channelName")
    attachment_count: Optional[int] = Field(alias="attachmentCount")
    links: Optional[List[Optional[Any]]]
    author: Optional["QueryContentsObservationsContentsResultsMessageAuthor"]
    mentions: Optional[
        List[Optional["QueryContentsObservationsContentsResultsMessageMentions"]]
    ]


class QueryContentsObservationsContentsResultsMessageAuthor(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsMessageMentions(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsPost(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    author: Optional["QueryContentsObservationsContentsResultsPostAuthor"]
    upvotes: Optional[int]
    downvotes: Optional[int]
    comment_count: Optional[int] = Field(alias="commentCount")
    links: Optional[List[Optional[Any]]]


class QueryContentsObservationsContentsResultsPostAuthor(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsObservationsContentsResultsPackage(BaseModel):
    file_count: Optional[int] = Field(alias="fileCount")
    folder_count: Optional[int] = Field(alias="folderCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")


class QueryContentsObservationsContentsResultsLanguage(BaseModel):
    languages: Optional[List[Optional[str]]]


class QueryContentsObservationsContentsResultsFeed(BaseModel):
    id: str
    name: str


class QueryContentsObservationsContentsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryContentsObservationsContentsResultsPages(BaseModel):
    index: Optional[int]
    text: Optional[str]
    relevance: Optional[float]
    images: Optional[
        List[Optional["QueryContentsObservationsContentsResultsPagesImages"]]
    ]
    chunks: Optional[
        List[Optional["QueryContentsObservationsContentsResultsPagesChunks"]]
    ]


class QueryContentsObservationsContentsResultsPagesImages(BaseModel):
    id: Optional[str]
    mime_type: Optional[str] = Field(alias="mimeType")
    data: Optional[str]
    left: Optional[int]
    right: Optional[int]
    top: Optional[int]
    bottom: Optional[int]


class QueryContentsObservationsContentsResultsPagesChunks(BaseModel):
    index: Optional[int]
    page_index: Optional[int] = Field(alias="pageIndex")
    row_index: Optional[int] = Field(alias="rowIndex")
    column_index: Optional[int] = Field(alias="columnIndex")
    confidence: Optional[float]
    text: Optional[str]
    role: Optional[TextRoles]
    language: Optional[str]
    relevance: Optional[float]


class QueryContentsObservationsContentsResultsSegments(BaseModel):
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    text: Optional[str]
    relevance: Optional[float]


class QueryContentsObservationsContentsResultsFrames(BaseModel):
    index: Optional[int]
    description: Optional[str]
    text: Optional[str]
    relevance: Optional[float]


class QueryContentsObservationsContentsResultsObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "QueryContentsObservationsContentsResultsObservationsObservable"
    related: Optional["QueryContentsObservationsContentsResultsObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[
        List[
            Optional["QueryContentsObservationsContentsResultsObservationsOccurrences"]
        ]
    ]
    state: EntityState


class QueryContentsObservationsContentsResultsObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryContentsObservationsContentsResultsObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class QueryContentsObservationsContentsResultsObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional[
        "QueryContentsObservationsContentsResultsObservationsOccurrencesBoundingBox"
    ] = Field(alias="boundingBox")


class QueryContentsObservationsContentsResultsObservationsOccurrencesBoundingBox(
    BaseModel
):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


QueryContentsObservations.model_rebuild()
QueryContentsObservationsContents.model_rebuild()
QueryContentsObservationsContentsResults.model_rebuild()
QueryContentsObservationsContentsResultsEmail.model_rebuild()
QueryContentsObservationsContentsResultsEvent.model_rebuild()
QueryContentsObservationsContentsResultsCommit.model_rebuild()
QueryContentsObservationsContentsResultsPullRequest.model_rebuild()
QueryContentsObservationsContentsResultsMessage.model_rebuild()
QueryContentsObservationsContentsResultsPost.model_rebuild()
QueryContentsObservationsContentsResultsPages.model_rebuild()
QueryContentsObservationsContentsResultsObservations.model_rebuild()
QueryContentsObservationsContentsResultsObservationsOccurrences.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SummarizationTypes


class SummarizeContents(BaseModel):
    summarize_contents: Optional[
        List[Optional["SummarizeContentsSummarizeContents"]]
    ] = Field(alias="summarizeContents")


class SummarizeContentsSummarizeContents(BaseModel):
    specification: Optional["SummarizeContentsSummarizeContentsSpecification"]
    content: Optional["SummarizeContentsSummarizeContentsContent"]
    type: SummarizationTypes
    items: Optional[List["SummarizeContentsSummarizeContentsItems"]]
    error: Optional[str]


class SummarizeContentsSummarizeContentsSpecification(BaseModel):
    id: str


class SummarizeContentsSummarizeContentsContent(BaseModel):
    id: str


class SummarizeContentsSummarizeContentsItems(BaseModel):
    text: Optional[str]
    tokens: int
    summarization_time: Optional[Any] = Field(alias="summarizationTime")


SummarizeContents.model_rebuild()
SummarizeContentsSummarizeContents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryPersonsExpanded(BaseModel):
    persons: Optional["QueryPersonsExpandedPersons"]


class QueryPersonsExpandedPersons(BaseModel):
    results: Optional[List[Optional["QueryPersonsExpandedPersonsResults"]]]


class QueryPersonsExpandedPersonsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryPersonsExpandedPersonsResultsOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[List[Optional["QueryPersonsExpandedPersonsResultsFeeds"]]]
    links: Optional[List[Optional["QueryPersonsExpandedPersonsResultsLinks"]]]
    workflow: Optional["QueryPersonsExpandedPersonsResultsWorkflow"]
    location: Optional["QueryPersonsExpandedPersonsResultsLocation"]
    h_3: Optional["QueryPersonsExpandedPersonsResultsH3"] = Field(alias="h3")
    address: Optional["QueryPersonsExpandedPersonsResultsAddress"]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")
    phone_number: Optional[str] = Field(alias="phoneNumber")
    birth_date: Optional[Any] = Field(alias="birthDate")
    title: Optional[str]
    occupation: Optional[str]
    education: Optional[str]
    works_for: Optional[
        List[Optional["QueryPersonsExpandedPersonsResultsWorksFor"]]
    ] = Field(alias="worksFor")
    affiliation: Optional[
        List[Optional["QueryPersonsExpandedPersonsResultsAffiliation"]]
    ]
    member_of: Optional[
        List[Optional["QueryPersonsExpandedPersonsResultsMemberOf"]]
    ] = Field(alias="memberOf")
    alumni_of: Optional[
        List[Optional["QueryPersonsExpandedPersonsResultsAlumniOf"]]
    ] = Field(alias="alumniOf")
    birth_place: Optional["QueryPersonsExpandedPersonsResultsBirthPlace"] = Field(
        alias="birthPlace"
    )
    death_place: Optional["QueryPersonsExpandedPersonsResultsDeathPlace"] = Field(
        alias="deathPlace"
    )
    home_location: Optional[
        List[Optional["QueryPersonsExpandedPersonsResultsHomeLocation"]]
    ] = Field(alias="homeLocation")
    work_location: Optional[
        List[Optional["QueryPersonsExpandedPersonsResultsWorkLocation"]]
    ] = Field(alias="workLocation")


class QueryPersonsExpandedPersonsResultsOwner(BaseModel):
    id: str


class QueryPersonsExpandedPersonsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryPersonsExpandedPersonsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryPersonsExpandedPersonsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryPersonsExpandedPersonsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryPersonsExpandedPersonsResultsWorksFor(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsAffiliation(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsMemberOf(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsAlumniOf(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsBirthPlace(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsDeathPlace(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsHomeLocation(BaseModel):
    id: str
    name: str


class QueryPersonsExpandedPersonsResultsWorkLocation(BaseModel):
    id: str
    name: str


QueryPersonsExpanded.model_rebuild()
QueryPersonsExpandedPersons.model_rebuild()
QueryPersonsExpandedPersonsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteConversations(BaseModel):
    delete_conversations: Optional[
        List[Optional["DeleteConversationsDeleteConversations"]]
    ] = Field(alias="deleteConversations")


class DeleteConversationsDeleteConversations(BaseModel):
    id: str
    state: EntityState


DeleteConversations.model_rebuild()
